==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/modplug/translations/modplug_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ru_RU">
<defaultcodec></defaultcodec>
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="40"/>
        <source>ModPlug Plugin</source>
        <translation>Модуль ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="44"/>
        <source>ModPlug Files</source>
        <translation>Файлы ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="108"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>Об аудио-модуле ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="109"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Аудио-модуль ModPlug для Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="110"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="111"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Основан на базе модуля Modplug для Xmms</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="112"/>
        <source>Modplug Plugin developers:</source>
        <translation>Разработчики модуля Modplug:</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="113"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="114"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="115"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="44"/>
        <source>File name:</source>
        <translation>Имя файла:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="45"/>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="46"/>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="47"/>
        <source>Length:</source>
        <translation>Длительность:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="48"/>
        <source>Speed:</source>
        <translation>Скорость:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="49"/>
        <source>Tempo:</source>
        <translation>Темп:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="50"/>
        <source>Samples:</source>
        <translation>Сэмплов:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="51"/>
        <source>Instruments:</source>
        <translation>Инструментов:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="52"/>
        <source>Patterns:</source>
        <translation>Образцов:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="52"/>
        <source>Channels:</source>
        <translation>Каналов:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>MOD Info</source>
        <translation>Иформация MOD</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="30"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="46"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="57"/>
        <source>Samples</source>
        <translation>Сэмплы</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="106"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="77"/>
        <source>Instruments</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="97"/>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="133"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>ModPlug Plugin Settings</source>
        <translation>Настройки модуля ModPlug</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="23"/>
        <source>Quality</source>
        <translation>Качество</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Resolution</source>
        <translation>Разрешение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>16 bit</source>
        <translation>16 бит</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>8 bit</source>
        <translation>8 бит</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Channels</source>
        <translation>Каналы</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Stereo</source>
        <translation>Стерео</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="77"/>
        <source>Mono (downmix)</source>
        <translation>Моно</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Resampling</source>
        <translation>Передискретизация</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Nearest (fastest)</source>
        <translation>Nearest (самый быстрый)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="106"/>
        <source>Linear (fast)</source>
        <translation>Linear (быстрый)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="113"/>
        <source>Spline (good quality)</source>
        <translation>Spline (хорошее качество)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="120"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>8-tap Fir (самое выскокое качество)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="136"/>
        <source>Sampling Rate</source>
        <translation>Дискретизация</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="142"/>
        <source>48000 Hz</source>
        <translation>48000 Гц</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="149"/>
        <source>44100 Hz</source>
        <translation>44100 Гц</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="156"/>
        <source>22050 Hz</source>
        <translation>22050 Гц</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="163"/>
        <source>11025 Hz</source>
        <translation>11025 Гц</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Effects</source>
        <translation>Эффекты</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="180"/>
        <source>Reverb</source>
        <translation>Затухание</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="457"/>
        <source>Depth (%)</source>
        <translation>Интенсивность (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="608"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="509"/>
        <source>Delay (ms)</source>
        <translation>Задержка (мс)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="282"/>
        <source>40</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="314"/>
        <source>Bass Boost</source>
        <translation>Усиление басов</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="326"/>
        <source>Amount (%)</source>
        <translation>Уровень (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="384"/>
        <source>Range (Hz)</source>
        <translation>Диапазон (Гц)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="416"/>
        <source>10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="448"/>
        <source>Surround</source>
        <translation>Эффект Surround (объёмное звучание)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="541"/>
        <source>5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="567"/>
        <source>Preamp</source>
        <translation>Усиление</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="576"/>
        <source>Volume</source>
        <translation>Громкость</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="646"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation type="unfinished">Замечание: установка слишком высокого
усиления может вызвать срезание!</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="661"/>
        <source>Misc</source>
        <translation>Дополнительно</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="667"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="673"/>
        <source>Use filename as song title</source>
        <translation>Использовать имя файла в качестве имени фрагмента</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="680"/>
        <source>Noise reduction</source>
        <translation>Шумоподавление</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Fast playlist info</source>
        <translation>Быстрое чтение информации</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Play Amiga MOD</source>
        <translation>Воспроизводить Amiga MOD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Looping</source>
        <translation>Повтор</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="716"/>
        <source>Don&apos;t loop</source>
        <translation>Не повторять</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="723"/>
        <source>Loop</source>
        <translation>Повторять</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="740"/>
        <source>time(s)</source>
        <translation>раз</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="760"/>
        <source>Loop forever</source>
        <translation>Повторять всегда</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="800"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="807"/>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="814"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/modplug/translations/modplug_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="60"/>
        <source>ModPlug Plugin</source>
        <translation>Модуль ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="64"/>
        <source>ModPlug Files</source>
        <translation>Файлы ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="133"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>Об аудио-модуле ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="134"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Аудио-модуль ModPlug для Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="135"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="136"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Основан на базе модуля Modplug для Xmms</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="137"/>
        <source>Modplug Plugin developers:</source>
        <translation>Разработчики модуля Modplug:</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="138"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="139"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="140"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="43"/>
        <source>File name:</source>
        <translation>Имя файла:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="44"/>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="45"/>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="46"/>
        <source>Length:</source>
        <translation>Длительность:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="47"/>
        <source>Speed:</source>
        <translation>Скорость:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="48"/>
        <source>Tempo:</source>
        <translation>Темп:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="49"/>
        <source>Samples:</source>
        <translation>Сэмплов:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="50"/>
        <source>Instruments:</source>
        <translation>Инструментов:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="51"/>
        <source>Patterns:</source>
        <translation>Образцов:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="52"/>
        <source>Channels:</source>
        <translation>Каналов:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>MOD Info</source>
        <translation>Иформация MOD</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="30"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="36"/>
        <location filename="../detailsdialog.ui" line="46"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="57"/>
        <source>Samples</source>
        <translation>Сэмплы</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="66"/>
        <location filename="../detailsdialog.ui" line="86"/>
        <location filename="../detailsdialog.ui" line="106"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="77"/>
        <source>Instruments</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="97"/>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="133"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>ModPlug Plugin Settings</source>
        <translation>Настройки модуля ModPlug</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="23"/>
        <source>Quality</source>
        <translation>Качество</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Resolution</source>
        <translation>Разрешение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>16 bit</source>
        <translation>16 бит</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>8 bit</source>
        <translation>8 бит</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Channels</source>
        <translation>Каналы</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Stereo</source>
        <translation>Стерео</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="77"/>
        <source>Mono (downmix)</source>
        <translation>Моно</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Resampling</source>
        <translation>Передискретизация</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Nearest (fastest)</source>
        <translation>Nearest (самый быстрый)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="106"/>
        <source>Linear (fast)</source>
        <translation>Linear (быстрый)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="113"/>
        <source>Spline (good quality)</source>
        <translation>Spline (хорошее качество)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="120"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>8-tap Fir (самое выскокое качество)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="136"/>
        <source>Sampling Rate</source>
        <translation>Дискретизация</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="142"/>
        <source>48000 Hz</source>
        <translation>48000 Гц</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="149"/>
        <source>44100 Hz</source>
        <translation>44100 Гц</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="156"/>
        <source>22050 Hz</source>
        <translation>22050 Гц</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="163"/>
        <source>11025 Hz</source>
        <translation>11025 Гц</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Effects</source>
        <translation>Эффекты</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="180"/>
        <source>Reverb</source>
        <translation>Затухание</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="192"/>
        <location filename="../settingsdialog.ui" line="457"/>
        <source>Depth (%)</source>
        <translation>Интенсивность (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="224"/>
        <location filename="../settingsdialog.ui" line="358"/>
        <location filename="../settingsdialog.ui" line="489"/>
        <location filename="../settingsdialog.ui" line="608"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <location filename="../settingsdialog.ui" line="509"/>
        <source>Delay (ms)</source>
        <translation>Задержка (мс)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="282"/>
        <source>40</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="314"/>
        <source>Bass Boost</source>
        <translation>Усиление басов</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="326"/>
        <source>Amount (%)</source>
        <translation>Уровень (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="384"/>
        <source>Range (Hz)</source>
        <translation>Диапазон (Гц)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="416"/>
        <source>10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="448"/>
        <source>Surround</source>
        <translation>Эффект Surround (объёмное звучание)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="541"/>
        <source>5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="567"/>
        <source>Preamp</source>
        <translation>Усиление</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="576"/>
        <source>Volume</source>
        <translation>Громкость</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="646"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation>Замечание: установка слишком высокого
усиления может вызвать срезание!</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="661"/>
        <source>Misc</source>
        <translation>Дополнительно</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="667"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="673"/>
        <source>Use filename as song title</source>
        <translation>Использовать имя файла в качестве имени фрагмента</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="680"/>
        <source>Noise reduction</source>
        <translation>Шумоподавление</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Fast playlist info</source>
        <translation>Быстрое чтение информации</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Play Amiga MOD</source>
        <translation>Воспроизводить Amiga MOD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Looping</source>
        <translation>Повтор</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="716"/>
        <source>Don&apos;t loop</source>
        <translation>Не повторять</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="723"/>
        <source>Loop</source>
        <translation>Повторять</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="740"/>
        <source>time(s)</source>
        <translation>раз</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="760"/>
        <source>Loop forever</source>
        <translation>Повторять всегда</translation>
    </message>
</context>
</TS>
